package com.jd.lightapplication.security;

import cn.hutool.core.util.StrUtil;
import com.jd.lightapplication.model.SysUser;
import com.jd.lightapplication.service.SysUserService;
import com.jd.lightapplication.utils.JwtUtils;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtException;
import lombok.AllArgsConstructor;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.web.authentication.www.BasicAuthenticationFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * 功能描述：Jwt拦截器
 *
 * @Author WaiterXiaoYY
 * @Date 2022/1/19 0:40
 * @Version 1.0
 */

public class JwtAuthenticationFilter extends BasicAuthenticationFilter {

    JwtUtils jwtUtils;

    UserDetailServiceImpl userDetailService;

    SysUserService sysUserService;


    public JwtAuthenticationFilter(AuthenticationManager authenticationManager, JwtUtils jwtUtils, UserDetailServiceImpl userDetailService, SysUserService sysUserService) {
        super(authenticationManager);
        this.jwtUtils = jwtUtils;
        this.sysUserService = sysUserService;
        this.userDetailService = userDetailService;
    }

    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain chain) throws IOException, ServletException {

        String jwt = request.getHeader(jwtUtils.getHeader());

        if (StrUtil.isBlankOrUndefined(jwt)) {
            chain.doFilter(request, response);
            return;
        }

        Claims claims = jwtUtils.getClaimByToken(jwt);

        if (claims == null) {
            throw new JwtException("token 异常");
        }

        if (jwtUtils.isTokenExpired(claims)) {
            throw new JwtException("token已过期");
        }

        String userId = claims.getSubject();

        SysUser sysUser = sysUserService.getById(userId);

        UsernamePasswordAuthenticationToken token = new UsernamePasswordAuthenticationToken(sysUser, null, userDetailService.getUserAuthority(sysUser.getId()));

        SecurityContextHolder.getContext().setAuthentication(token);

        chain.doFilter(request, response);
    }
}
